.TH ODE L

.SH NAME
ode - integrates a system of ordinary differential equations.

.SH SYNOPSIS
ode
.I [foo(.dat)]

.SH DESCRIPTION
.I ode
will integrate a system of ordinary differential equations using a
fourth order Runge-Kutta integrator and write the
output to
.I foo.dat
(default is standard output).  The output will be in the form of a
column where each row contains numbers the first of which is the independent
variable (e.g. time) and the rest of which are the degrees of freedom
selected by the user to be written.  Each number is separated by a space.
.P
When
.I ode
is executed, if the output is directed to
.I foo.dat,
it first looks for a file
.I odeinp.odeinp
from which to read input parameters, then it looks for
.I foo.odeinp.
If neither of these files are present, the input parameters are read from
standard input.  If the output is sent to standard output, the input will
have to be entered by standard input.
.P
The input parameters are:
.HP
- The parameters for the ode (see below).
.HP
- The initial conditions for the ode.
.HP
- The initial value of the independent variable.
.HP
- The final value for the independent variable.  This may be less than the
initial value.
.HP
- The time step for the integration.
.HP
- The degrees of freedom to be written.
.P
.I ode
will prompt the user for these parameters, so it should be clear in practice
how this is done.

.SH SPECIFYING THE DIFFERENTIAL EQUATION
The differential equation to be integrated must be specified when
.I ode
is compiled.  The first thing to change is the value of
.I NDOF
in
.I ode.h.
This should be the number of degrees of freedom of the differential equation
you are integrating.  At compilation the function
.I derivs.c
is compiled and linked as part of the
.I ode
executable.  In
.I derivs.c
you specify the right hand side of the ordinary differential equation you
wish to integrate.  An example of a differential equation is:
.P
.RS
.nf

/* Here's the formula for the ode. */
/* These are the equations for a mass spring system. */
/* The variables are:
   y[0] -> x
   y[1] -> xdot
   */
 
#include<math.h>
#include "ode.h"
 
double parms[10];
 
derivs(t,y,ydot)
 
double t,y[NDOF],ydot[NDOF];
 
{
  ydot[0] = y[1];
  ydot[1] = -parms[0] * y[0];
}

.fi
.RE
.P
It is probably best to simply modify the version of
.I derivs.c
which comes with the source code for
.I ode.
If your ode will have parameters, the declaration of
.I parms
must appear.  If you will be using more than 10 parameters, then the
value must also be changed in
.I ode.c.
For more on parameters, see below.

.SH
.SH SPECIFYING PARAMETERS
It is possible with
.I ode
to specify parameters for the differential equation without having to
recompile the program.  This is done by the function
.I parmenter.c
which is compiled and linked when
.I func
is compiled.  A typical example of
.I parmenter.c
is
.P
.RS
.nf

/* Here is where the parameters are entered. */
/* The parameters are:
   parms[0] -> omega
   */
 
#include<stdio.h>
#include<math.h>
 
parmenter(parms,input_fp,log_fp,UsingStdIn)
 
double parms[10];
FILE *input_fp,*log_fp;
char UsingStdIn;
 
{
  double k,m;
 
  printf("\\nEnter the value of mass in kg.\\n");
  fscanf(input_fp,"%lf",&m);
  if (!UsingStdIn) {
    fprintf(log_fp,"\\nThe value of mass is: %lf kg\\n",m);
  }
 
  printf("\\nEnter the value of the spring constant in N/m.\\n");
  fscanf(input_fp,"%lf",&k);
  if (!UsingStdIn) {
    fprintf(log_fp,"\\nThe value of the spring constant is: %lf N/m",k);
  }
 
  parms[0] = sqrt(k / m);
 
}

.fi
.RE
.P
You should modify the version of
.I parmenter.c
given with the source code for
.I ode.
The same comments about the array
.I parms
hold here as were made for function specification above.

.SH TWEAKING INITIAL CONDITIONS
Sometimes it is advantageous to be able to do some computations with the
initial conditions for the ode internally rather than by hand.  This is
done by the function
.I ichacks.c
which is compiled and linked when
.I ode
is compiled.  An example of an
.I ichacks file is:
.P
.RS
.nf

/* Here are the initial condition hacks. */
 
#include<math.h>
#include "ode.h"
 
double parms[10];
 
ichacks(y)
 
double y[NDOF];
 
{
  y[1] = 2.0 * y[0];
}

.fi
.RE
.P
You should modify the version of
.I ichacks.c
given with the source code for
.I ode.
The same comments about the array
.I parms
hold here as were made for function specification above.

.SH FILES
.TP 2.2i
.I %%binpath-name%%/ode
executable file.
.TP 2.2i
.I %%demopath-name%%/derivs.c
an example of
.I derivs.c.
.TP 2.2i
.I %%demopath-name%%/parmenter.c
an example of
.I parmenter.c.
.TP 2.2i
.I %%demopath-name%%/ichacks.c
an example of
.I ichacks.c.
.TP 2.2i
.I %%doc-name%%
.I LaTeX
documentation file.

.SH DIAGNOSTICS
If the data is not written to standard output, a log file,
.I foo.odelog,
is created which contains a record of the input parameters.

.SH AUTHOR
Andrew D. Lewis, Queen's University, Kingston, ON, Canada,
<andrew@mast.queensu.ca>.
